@@ -1,15 +1,34 @@
-#!/usr/bin/env python
+﻿#!/usr/bin/python
 # -*- coding: utf-8 -*-
 
 from utils.DebugLog import DebugLog
 from PyQt4 import QtCore
 
 class Ride:
-   def __init__(self, train, heure, destination, voie):
+   def __init__(self):
+      self.train = ''
+      self.heure = ''
+      self.destination = ''
+      self.voie = ''
+      self.error = ''
+      
+   def setTrain(self, train):
       self.train = train
+     
+   def setHeure(self, heure):
       self.heure = heure
+   
+   def setDestination(self, destination):
       self.destination = destination
-      self.voie = voie
+     
+   def setVoie(self, voie):
+      self.voie = voie  
+      
+   def setError(self, error):
+      self.error = error
+      
+   def __str__(self):
+      return unicode('Train: %s, Heure: %s, Destination: %s, Voie: %s'%(self.train, self.heure, self.destination, self.voie))
 
 class RideModel(QtCore.QObject):
    def __init__(self, id):
