@@ -202,11 +202,15 @@ class AddRideDlg(QtGui.QDialog ):
       req="SELECT name, code, exploitant, position FROM gares, lignes WHERE gares.name='%s' AND gares.rowid=lignes.gareid AND ligne='%s'" % (depart, ligne)
       DebugLog(req)
       c = self.db.execute(req)
+      
       res = c.fetchone()
       if not res:
          return False
 
-      DebugLog("rer?metro? :"+str(res))
+      DebugLog(str(res))         
+      for res in c:
+         DebugLog(str(res))
+      
       tec = ''
       if ligne[0]=='M':
          tec = 'Metro'
@@ -219,23 +223,28 @@ class AddRideDlg(QtGui.QDialog ):
 
       depart = res[0]
       codeDepart = res[1]
-      exploitant = res[2]
+      exploitantD = res[2]
       posDepart = 0
       posArrivee = 0
 
       if res[3]:
          posDepart = int(res[3])
 
-      req = "SELECT name, code, position FROM gares, lignes WHERE gares.name='%s' AND gares.rowid=lignes.gareid AND ligne='%s'" % (arrivee, ligne)
+      req = "SELECT name, code, exploitant, position FROM gares, lignes WHERE gares.name='%s' AND gares.rowid=lignes.gareid AND ligne='%s'" % (arrivee, ligne)
       DebugLog(req)
       c = self.db.execute(req)
       res = c.fetchone()
+      
+      DebugLog(str(res))
+      for res in c:
+         DebugLog(str(res))
 
       ligne = ligne[1:]
       arrivee = res[0]
       codeArrivee = res[1]
-      if res[2]:
-         posArrivee = int(res[2])
+      exploitantA = res[2]
+      if res[3]:
+         posArrivee = int(res[3])
 
       if posDepart-posArrivee>0:
          direction = 'A'
@@ -246,7 +255,7 @@ class AddRideDlg(QtGui.QDialog ):
 
       DebugLog('posD=%d, posA=%d, dir=%s'%(posDepart, posArrivee, direction))
 
-      l = Ride(ligne, tec, depart, arrivee, codeDepart, codeArrivee, exploitant, direction)
+      l = Ride(ligne, tec, depart, arrivee, codeDepart, codeArrivee, exploitantA, direction)
       self.garesConf.AddRide(l)
       return l
 
