@@ -10,7 +10,7 @@ from view.CircleProgress import CircleProgress
 
 class RideView(QtGui.QWidget):
    def __init__(self, model, parent):
-      DebugLog("RideView::__init__")
+#      DebugLog("RideView::__init__")
       super(QtGui.QWidget, self).__init__(parent)
 
       self.iconsPath = os.path.join(os.path.dirname(getScriptPath()), 'icons')
@@ -32,7 +32,6 @@ class RideView(QtGui.QWidget):
       return os.path.join(self.iconsPath, str)
 
    def PrepareWidget(self):
-      DebugLog("RideView::PrepareWidget")
       self.layout = QtGui.QGridLayout(self)
       self.layout.setMargin(0)
       self.layout.setSpacing(0)
@@ -59,7 +58,6 @@ class RideView(QtGui.QWidget):
       self.progress.setFixedHeight(0)
 
    def PrepareIcons(self):
-      DebugLog("RideView::PrepareIcons")
       self.statusIconLayout = QtGui.QHBoxLayout()
       self.statusIconLayout.setSizeConstraint( QtGui.QLayout.SetNoConstraint )
       self.statusIconLayout.setAlignment(Qt.AlignCenter)
@@ -86,7 +84,6 @@ class RideView(QtGui.QWidget):
       self.layout.addLayout( self.statusIconLayout, 0, 3, 1, 1, Qt.AlignCenter )
 
    def PrepareTitle(self):
-      DebugLog("RideView::PrepareTitle")
       iconLayout = QtGui.QHBoxLayout()
       iconLayout.setMargin(0)
       iconLayout.setSpacing(0)
@@ -170,7 +167,7 @@ class RideView(QtGui.QWidget):
          self.timer.start()
 
    def UpdateRides(self):
-      DebugLog("RideView::UpdateRides")
+      DebugLog("RideView::UpdateRides %s"%self.model.id)
       irow=2
       height=48
       self.font.setPointSize(14)
@@ -180,14 +177,17 @@ class RideView(QtGui.QWidget):
       for line in self.model.getRides():
          color = self.colors[irow%2]
 
-         if line.train=='Aucun train pour ce trajet':
-            #self.SetLabel(irow, 0, '',        '#fff', color, 200, 0, self.font)
-            self.SetLabel(irow, 0, line.train,        '#fff', color, 200, 0, self.font, Qt.AlignLeft|Qt.AlignVCenter, 4)
+         if line.error:
+            self.SetInfo('ERROR', line.error)
          else:
-            self.SetLabel(irow, 0, line.train,        '#fff', color, 70,  90, self.font)
-            self.SetLabel(irow, 1, line.heure,     '#FFCD00', color, 0,  0, self.font)
-            self.SetLabel(irow, 2, line.destination,  '#fff', color, 400, 0, self.font, Qt.AlignLeft|Qt.AlignVCenter)
-            self.SetLabel(irow, 3, line.voie,         '#fff', color, 40,  50, self.font)
+            if line.train=='Aucun train pour ce trajet':
+               #self.SetLabel(irow, 0, '',        '#fff', color, 200, 0, self.font)
+               self.SetLabel(irow, 0, line.train,        '#fff', color, 200, 0, self.font, Qt.AlignLeft|Qt.AlignVCenter, 4)
+            else:
+               self.SetLabel(irow, 0, line.train,        '#fff', color, 70,  90, self.font)
+               self.SetLabel(irow, 1, line.heure,     '#FFCD00', color, 0,  0, self.font)
+               self.SetLabel(irow, 2, line.destination,  '#fff', color, 400, 0, self.font, Qt.AlignLeft|Qt.AlignVCenter)
+               self.SetLabel(irow, 3, line.voie,         '#fff', color, 40,  50, self.font)
 
          irow += 1
 
@@ -223,15 +223,16 @@ class RideView(QtGui.QWidget):
    def SetInfo(self, stype, text):
       if stype=='ERROR':
          self.progress.setStyleSheet("color: #fff; background: #f00; padding:5px; margin:0; ")
-         self.infoButton.setIcon(QtGui.QIcon( QtGui.QPixmap(self.IconPath('error.png')).scaled(32,32) ))
+         self.infoButton.setIcon(QtGui.QIcon( QtGui.QPixmap(self.IconPath('error.png')) ))
          self.infoButton.show()
+         self.ShowInfo()
 
       elif stype=='PROGRESS':
          self.progress.setStyleSheet("color: #fff; background: #2684DB; padding:5px; margin:0; ")
 
       elif stype=='WARNING':
          self.progress.setStyleSheet("color: #000; background: #FFCD00; padding:5px; margin:0; ")
-         self.infoButton.setIcon(QtGui.QIcon( QtGui.QPixmap(self.IconPath('warning.png')).scaled(32,32) ))
+         self.infoButton.setIcon(QtGui.QIcon( QtGui.QPixmap(self.IconPath('warning.png')) ))
          self.infoButton.show()
 
       self.progress.setText(text)
