@@ -147,7 +147,7 @@ class TrainTrainView(QtGui.QMainWindow):
 #      self.tabW.addTab(self.scrollArea, 'Mes Trains')
 #      self.tabW.addTab(addButton, 'Horaire')
 
-#      self.setCentralWidget(self.tabW) #self.scrollArea)
+#      self.setCentralWidget(self.tabW)
       self.setCentralWidget(self.scrollArea)
 
       self.connect(self.model, QtCore.SIGNAL('extracted'), self.Extracted, QtCore.Qt.QueuedConnection)
@@ -156,22 +156,19 @@ class TrainTrainView(QtGui.QMainWindow):
    def Resized(self, val):
       desktop = QtGui.QApplication.desktop()
 
-      if desktop.screenGeometry().width() > desktop.screenGeometry().height():
-         self.tabW.setTabPosition(QtGui.QTabWidget.East)
-      else:
-         self.tabW.setTabPosition(QtGui.QTabWidget.South)
+#      if desktop.screenGeometry().width() > desktop.screenGeometry().height():
+#         self.tabW.setTabPosition(QtGui.QTabWidget.East)
+#      else:
+#         self.tabW.setTabPosition(QtGui.QTabWidget.South)
 
    def Refresh(self):
       DebugLog("TrainTrainView::Refresh")
       self.updateCpt=0
       self.SetLoading(True)
-
-      if self.refreshId:
-         self.views[self.refreshId].Refresh()
-      else:
-         for view in self.views.values():
-            view.Busy()
-         self.model.RefreshDatas()
+      
+      for view in self.views.values():
+         view.Busy()
+      self.model.RefreshDatas()
 
    def RefreshAuto(self):
       if self.timer.isActive():
